import re

import psutil


def cal_page_count(total_count: int, per_page_count: int) -> int:
    """
    根据总条数和每页数量计算页数

    Args:
        total_count: 总条数
        per_page_count: 每页数量

    Returns:
        总页数
    """

    if total_count >= 0 and per_page_count > 0:
        if total_count == 0:
            return 1
        else:
            return total_count // per_page_count if total_count % per_page_count == 0 else total_count // per_page_count + 1
    else:
        raise ValueError("总条数total_count必须>=0，每页数量per_page_count必须>0")


def has_invalid_windows_chars(string: str) -> bool:
    """
    检测windows下，字符串是否包含非法字符
        - <>:"/\|?*：这些字符在Windows中被视为非法字符。
        - \x00-\x1f：这些字符是ASCII控制字符，也被视为非法字符。

    Args:
        string: 需要检测的字符串

    Returns:
        检测结果：包含为True，不包含为False
    """

    pattern = r'[<>:"/\\|?*\x00-\x1f]'
    return bool(re.search(pattern, string))


def get_pids_by_exe_name(exe_name: str) -> list:
    """
    根据exe名称获取所有pid

    Args:
        exe_name: exe名称。示例：

    Returns:
        pid列表
    """

    return [p.pid for p in psutil.process_iter() if p.name() == exe_name]


def get_exe_name_by_pid(pid: int) -> str:
    """
    根据pid获取exe名称

    Args:
        pid: 进程id

    Returns:
        exe名称
    """

    result = ""
    for p in psutil.process_iter():
        if p.pid == pid:
            result = p.name()
    return result


if __name__ == '__main__':
    print(cal_page_count(11, 5))
    print(has_invalid_windows_chars("gg*geg"))
    print(get_pids_by_exe_name("QQBrowser.exe"))
    print(get_exe_name_by_pid(17044))



import datetime


def datetime_to_timestamp(dt: datetime.datetime, style=None):
    """
    datetime转时间戳

    示例：
    t = datetime.datetime(2012, 12, 12, 23, 59, 59, 48000)
    result = datetime_to_timestamp(t)       ->   1355327999.048 (float)
    result = datetime_to_timestamp(t, 10)   ->   1355327999 (int)
    result = datetime_to_timestamp(t, 13)   ->   1355327999048 (int)

    :param dt: 日期时间
    :param style: 时间戳类型
    :return:
    """

    if type:
        if str(style) == '10':
            return int(round(dt.timestamp()))

        if str(style) == '13':
            return int(round(dt.timestamp() * 1000))

    return dt.timestamp()


def timestamp_to_datetime(ts, tz=None) -> datetime.datetime:
    """
    时间戳转datetime

    :param ts: 时间戳
    :param tz: 时区。默认是本地
    :return:
    """
    if len(str(ts)) == 13:
        if tz == 'utc':
            return datetime.datetime.utcfromtimestamp(ts / 1000)
        return datetime.datetime.fromtimestamp(ts / 1000)
    if tz == 'utc':
        return datetime.datetime.utcfromtimestamp(ts)
    return datetime.datetime.fromtimestamp(ts)


def datetime_to_string(dt: datetime.datetime, style: str = '%Y-%m-%d %H:%M:%S') -> str:
    """
    datetime转字符串

    :param dt: 日期时间
    :param style: 转换格式
    :return:
    """
    if style == 'whole':
        return dt.strftime('%Y-%m-%d %H:%M:%S.%f')
    if style == 'date':
        return dt.strftime('%Y-%m-%d')
    if style == 'time':
        return dt.strftime('%H:%M:%S')
    else:
        return dt.strftime(style)


def string_to_datetime(s: str, style: str = None) -> datetime.datetime:
    """
    字符串转datetime

    示例：
    string_to_datetime('2022-02-11 13:44:01.48000')            ->   2022-02-11 13:44:01.480000
    string_to_datetime('2022-02-11 13:44:01')                  ->   2022-02-11 13:44:01
    string_to_datetime('2022-02-11')                           ->   2022-02-11 00:00:00
    string_to_datetime('2022-02-11 13:44:01.48000', '%Y-%m')   ->   2022-02-01 00:00:00

    :param s: 日期时间
    :param style: 转换格式
    :return:
    """
    s = s.strip()
    f = ''

    if style:
        f = style

    else:
        flag = False

        if len(s) == 10:
            f = '%Y-%m-%d'
            flag = True

        if len(s) == 19:
            f = '%Y-%m-%d %H:%M:%S'
            flag = True

        if '.' in s:
            f = '%Y-%m-%d %H:%M:%S.%f'
            flag = True

        if not flag:
            raise Exception('格式有误')

    return datetime.datetime.strptime(s, f)


def local_to_utc(dt: datetime.datetime) -> datetime.datetime:
    """
    本地时间转utc时间

    :param dt:
    :return:
    """
    return dt - datetime.timedelta(hours=8)


def utc_to_local(dt: datetime.datetime) -> datetime.datetime:
    """
    utc时间转本地时间

    :param dt:
    :return:
    """
    return dt + datetime.timedelta(hours=8)
